function muasymmetry(varargin)
% usage MUASYMMETRY
%
% for MUFIT reads MU_MODEL.GROUPING and loads into MU_DATA.TIME
% MU_DATA.ASYMMETRY and MU_DATA.ASYMERROR
%
% usage MUASIMMETRY(1)
%
% for MUPLOT reads MU_PLOT.GROUPING and loads into MU_PLOT.TIME and
% MU_PLOT.ASYMMETRY

global MU_DATA MU_MODEL MU_GEAR MU_TABLE MU_PLOT
  
if isempty(varargin)
    % MUFIT version
    histos=[MU_MODEL.GROUPING(1).FORWARD ...
            MU_MODEL.GROUPING(1).BACKWARD]; % full grouping
else
    % MUPLOT version
    histos=[MU_PLOT.GROUPING(1).FORWARD ...
            MU_PLOT.GROUPING(1).BACKWARD]; % full grouping        
end
off=MU_GEAR.OFFSET;
switch MU_GEAR.FACILITY
  case 'PSI'
    lengthdata=size(MU_DATA.DATA,1)-max(MU_DATA.NT0(histos))-off+1;
    % calculate background on pre-prompt region
    % histos are zeros initially, then they count background
    % until the prompt (t=0) followed by positrons from the 
    % muon decays for t>=0. Background is the average of the
    % pre-prompt region, 
    bkgsave=zeros(size(histos));
    k=0;
    data=zeros(lengthdata,length(histos)); % each histogram it is a column vector
    errors=data;
    for h=histos  % histos could be e.g. [3 4]
        nt0=MU_DATA.NT0(h);
        k=k+1; % k is 1 for h=3 and 2 for h=4 
        firstbkg=find(MU_DATA.DATA(1:end-1000,h), 1 )+MU_GEAR.LBG; % first
                                                          % bin for
                                                          % background        
        lastbkg=nt0-MU_GEAR.RBG; % last bin for bakground guess
        initial=nt0+off-1;  % first bin is MU_GEAR.OFFSET-1  bins after
                            % that containing t=0 (MU_GEAR.OFFSET=1
                            % starts from t=0)
        
        bins=initial:initial+lengthdata-1;
                                                   % for each histo
        switch MU_GEAR.INSTRUMENT
          case {'GPS','LTF'} % mode is only valid in GPS where MORE could apply
           if  isfield(MU_GEAR,'BCKG') % for backward compatibility
               if strcmpi(MU_GEAR.BCKG,'TAIL')
                   lasthist=size(MU_DATA.DATA,1);
                   first=ceil(lasthist/2);
                   x=exp(-(first:lasthist)'*MU_DATA.RESNS/MU_TABLE.TAUMU);
                   y=MU_DATA.DATA(first:lasthist,h);
                   p=polyfit(x,y,1); % linear fit of Nexp(-t/tau)+B vs exp(-t/tau)
                   bkg=p(2);
               else
                   bkg=mean(MU_DATA.DATA(firstbkg:lastbkg,h)); % head
               end
           end
          otherwise
            bkg=mean(MU_DATA.DATA(firstbkg:lastbkg,h)); % head
        end        
        switch MU_GEAR.INSTRUMENT
          case {'GPS','LTF'} % mode is only valid in GPS where MORE could apply
           if  isfield(MU_GEAR,'MODE') % for backward compatibility
               if strcmpi(MU_GEAR.MODE,'MORE') 
                   background=0; % do not subtract background
               else
                   background=1; % subtract background
               end
           end
          otherwise
            background=1;
        end
        subtract=MU_DATA.DATA(bins,h)-background*bkg;
        subtract(subtract<0)=0; % to correct bins with counts less than bkg
        % background is the MORE switch
        errors(:,k)=sqrt(MU_DATA.DATA(bins,h)); % detector by detector
        data(:,k)=subtract; %remember, k=1 for h=3 and k=2 for h=4!                                       
        bkgsave(k)=background*bkg;                                         
    end
    errors(errors==0)=1; % must be strictly positive define
    MU_DATA.BACKGROUNDS=bkgsave;
        % these are counts minus background counts which
        % occasionally go negative, although counts cannot be
        % negative (and poissonian noise sqrt(counts) will complain
        % if this happens)
        % data(find(data<0))=0; % negative bins are sets to zero  
    % nt0(h) contains time t=0     
    % background subtraction only on used histos
  case 'ISIS'
    nt0=MU_DATA.NT0(histos(1)); % t=0 bins for all histo in the grouping
                                % all histo in
                                % the chosen grouping
                                % equal for all histos at ISIS
    lengthdata=size(MU_DATA.DATA,1)-nt0-off+1;
    initial=nt0+off;  % first bin is MU_GEAR.OFFSET  bins after
                        % that containing t=0 (MU_GEAR.OFFSET=0
                        % starts from t=0)
    bins=initial:initial+lengthdata-1;
    k=0;
    data=zeros(lengthdata,length(histos)); % each histogram it is a column vector
    for h=histos
        k=k+1;
        data(:,k)=MU_DATA.DATA(bins,h); 
    end
    errors=sqrt(data); % usual Poisson std dev for data with zero bkg
    errors(errors==0)=1; % must be strictly positive defined
end

if isempty(varargin)
    % MUFIT version
    weightplus=[ones(size(MU_MODEL.GROUPING(1).FORWARD)) ...
                MU_MODEL.ALPHA*ones(size(MU_MODEL.GROUPING(1).BACKWARD))]';
else
    % MUPLOT version
    weightplus=[ones(size(MU_PLOT.GROUPING(1).FORWARD)) ...
                MU_PLOT.ALPHA*ones(size(MU_PLOT.GROUPING(1).BACKWARD))]';
end
% for the denominator of the asymmetry function
dt=MU_DATA.DT(histos); % distance of t=0 from center of bin NT0
dt=mean(dt); % take average over histos in this grouping
             %
             % now fit N0 for the denominator in polarization
Y=(data* ...
  weightplus)'; % sum of all histos
% eX=sqrt(data*(weightplus.^2)'); % sigma^2=data*weight^2, 
% a=X(1);
% not needed with polyfit
X=exp((-(off-1+[0:lengthdata-1])*MU_DATA.RESNS+dt)/MU_TABLE.TAUMU);
% recreating time vector, [0:lengthdata-1] is like nt0-1
% off-1 adds offset so that if off is the bin, counted from nt0
% (e.g. off=1 means that the first good bin is displaced by off-1=0
% bins)
% Now X is the decay from time t=0 to the center of the first good
% bin. Let's assume again that off=1. The formula yields
% exp(-dt/TAUMU) for the t=0 bin, so dt must be the shift FORWARD
% from the bin center (i.e. dt is POSITIVE if t=0 is to the RIGHT
% of the nt0 bin center). See MUSET.M that has the same logic 


N0=polyfit(X,Y,1); % fits Y vs exp(-time(ns)/taumu(ns))
N0=N0(1);


if isempty(varargin)
    % MUFIT version
    weight=[ones(size(MU_MODEL.GROUPING(1).FORWARD)) ...
            (-MU_MODEL.ALPHA)* ...
            ones(size(MU_MODEL.GROUPING(1).BACKWARD))]'; % columns vector
    MU_DATA.TIME=((off-1+(0:lengthdata-1))*MU_DATA.RESNS-dt)/1000; 
    % including offset and fine adjustment dt, finally transformed in musec
    % row vector
    MU_DATA.ASYMMETRY=((data*weight/N0)...
        .*exp(MU_DATA.TIME'/(MU_TABLE.TAUMU/1e3)))';
    % here taumu is in mus
    % data*weight is a column vector and is multiplied element-wise 
    % by a column vector; the result is transposed to a row vector 
   
    % errors associated with asymmetry, according to the above definition
    %
    % A = exp(t/tau)/N0 (sum_i=1^F N_i - alpha sum_j=1^B N_j)
    %
    % are
    %
    % e= exp(t/tau)/N0 sqrt(sum_i=1^F dN_i^2 + alpha^2 sum_j=1^B dN_j^2)
    %
    MU_DATA.ASYMERROR=((sqrt(errors.^2*weight.^2)/N0)...
       .*exp(MU_DATA.TIME'/(MU_TABLE.TAUMU/1e3)))'; % now errors are on counts
%    MU_DATA.ASYMERROR=(sqrt(data*(weight.^2))/N0...
%                       .*exp(MU_DATA.TIME'/(MU_TABLE.TAUMU/1e3)))';
else
    % MUPLOT version
    weight=[ones(size(MU_PLOT.GROUPING(1).FORWARD)) ...
        (-MU_PLOT.ALPHA)* ...
        ones(size(MU_PLOT.GROUPING(1).BACKWARD))]';
    MU_PLOT.TIME=((off-1+(0:lengthdata-1))*MU_DATA.RESNS-dt)/1000; 
    % including offset and fine adjustment dt, finally transformed in musec
    MU_PLOT.ASYMMETRY=((data*weight/N0).*exp(MU_DATA.TIME'/ ...
                                         (MU_TABLE.TAUMU/1e3)))';
    % here taumu is in mus
end

% Student's t or Gosset from Guinness.
% sqrt(n) is underestimation of stdev for n small.
