function muload(varargin)
% MULOAD
% opens a gui
%
% MULOAD(N)
% loads NRUN + n
%
% MULOAD(ZP,NRUN)
% ZP is the number of characters for nrun to be zero padded 
% NRUN is the run number (integer)
% Loads data from a run, using the path and filename information
% NRUN will be saved in the integer variable MU_DATA.NRUN
% Raw data are stored in global structure MU_DATA.DATA
% Other fields are
% RESNS (ns/bin)
% START_TIME, START_DATE, STOP_TIME, STOP_DATE
% TITLE, SAMPLE, ORIENTATION, FIELD , TEMPERATURE, COMMENTS
    
    
global MU_GEAR MU_TABLE MU_PATH MU_DATA
narg=size(varargin,2);
%localdir='';
filename='';
%pathname='';

switch narg
  case 0
    if isstruct(MU_PATH)
        %localdir=pwd;
        %cd(MU_PATH.DATA)
        [filename pathname s]=uigetfile([MU_PATH.DATA '*.' ...
                            MU_GEAR.FILENAME_SUFFIX],...
                                        'LOAD MUSR DATA RUN');
    else 
        [filename pathname s]=uigetfile(['*.' ...
                            MU_GEAR.FILENAME_SUFFIX],...
                                        'LOAD MUSR DATA RUN');
    end
%     if ~isempty(localdir)
%         cd(localdir)
%     end
    if ~s
        filename='';
    end
    if  ~isempty(filename)
        if ~strcmp(pathname,MU_PATH.DATA) 
            MU_PATH.DATA=pathname;   % change data path
        end
        file=filename;
        filename=[MU_PATH.DATA filename];
        npre=length(MU_GEAR.FILENAME_PREFIX);
        nsuf=length(MU_GEAR.FILENAME_SUFFIX);
        if strncmp(MU_GEAR.FILENAME_PREFIX,...
                   file,npre) & ...
                strcmp(MU_GEAR.FILENAME_SUFFIX,file(end-nsuf+1: ...
                                                        end)) & ...
                ~isempty(str2num(...
                    file(npre+1:end-nsuf)))
            nrun=str2num(file(npre+1:end-nsuf));
            MU_DATA.NRUN=nrun;
            zeropad='00000000000000000';
            zp=length(file(npre+1:end-nsuf-1))-...
               length(num2str(MU_DATA.NRUN));
            zeropad=zeropad(1:zp);
            MU_DATA.ZEROPAD=zeropad;
        else 
            disp([MU_GEAR.FILENAME_PREFIX ':' ...
                  file(1:npre)])
            disp([MU_GEAR.FILENAME_SUFFIX ':' ...
                  filename(end-nsuf+1:end)])
            disp(file(npre+1:end-nsuf))
            disp('Prefix or suffix do not match. Use mufilename')
            filename='';
        end
        
    end
  case 1
    n=length(num2str(MU_DATA.NRUN));


    if isstruct(MU_DATA)
        nrun=MU_DATA.NRUN+varargin{1};
        MU_DATA.NRUN=nrun;
        if length(num2str(MU_DATA.NRUN))>n  % increases number of digits
            zeropad=MU_DATA.ZEROPAD;        
            zeropad=zeropad(1:end-1);  % decrease zeropadding
            MU_DATA.ZEROPAD=zeropad;
        end
        filename=strcat(MU_PATH.DATA,MU_GEAR.FILENAME_PREFIX,...
                        MU_DATA.ZEROPAD,num2str(MU_DATA.NRUN),...
                        '.',MU_GEAR.FILENAME_SUFFIX);
    else
        disp(['No run selected yet! Cannot load NRUN=NRUN+' n]);
    end
        
  case 2
    zp=varargin{1}; % varargin{1} (cell of cell array) is passed as a number
    nrun=varargin{2}; % also nrun is passed as a number,
                                % why doesn't it require str2num? it's a cell
    if isnumeric(nrun)
        zeroes='0000000000000000000';
        s=int2str(nrun);
        zeropad=zeroes(1:zp-length(s));
        if length(s)<zp, s=[zeropad s]; end
        filename=strcat(MU_PATH.DATA,MU_GEAR.FILENAME_PREFIX,...
                        s,'.',MU_GEAR.FILENAME_SUFFIX);
        MU_DATA.NRUN=nrun;
        MU_DATA.ZEROPAD=zeropad;
    else
        disp('nrun must be a number!')
    end
end
if ~isempty(filename)
    if exist(filename)

        clear global MU_ADD % this is a fresh load, MU_ADD contains
                            % added runs
        switch MU_GEAR.FACILITY
          case 'PSI'
            [histos dt head psi_structure]=psiclassload(filename); %new psi class
            MU_DATA.PSI_STRUCTURE=psi_structure;
% fourth output is a self explaing structurepsi
          case 'ISIS'
            switch MU_GEAR.DATA_TYPE
              case 'MCS'
                [histos dt head]=isisload(filename);
              case 'NEXUS'
                [histos dt head]=nxsload(filename);
            end 
        end
        nrun=MU_DATA.NRUN;
        zeropad=[];
        if isfield(MU_DATA,'ZEROPAD')
            zeropad=MU_DATA.ZEROPAD;
        end
        clear global MU_DATA
        global MU_DATA
        MU_DATA.NRUN=nrun;
        MU_DATA.ZEROPAD=zeropad;
        MU_DATA.DATA=histos; %
        if isfield(MU_GEAR,'NT0') % if a proper estimate was done 
                                  % by muset, or inherited from
                                  % MULAB.mat, use it
            MU_DATA.NT0=MU_GEAR.NT0;
        else
            MU_DATA.NT0=muguesst0(histos); % rough guess
            MU_GEAR.NT0=MU_DATA.NT0; % rough better than nothing
        end
        if isfield(MU_GEAR,'DT') % if a proper estimate was done 
                                 % by muset, or inherited from
                                 % MULAB.mat, use it
            MU_DATA.DT=MU_GEAR.DT;
        else
            MU_DATA.DT=zeros(1,size(histos,2)); % rough guess
            MU_GEAR.DT=MU_DATA.DT; % rough better than nothing
        end
        MU_DATA.RESNS=dt/1000;
        h=char(head);  % check, this is OK for PSI!!!!
        MU_DATA.START_DATE=h(3,16:24);
        MU_DATA.STOP_DATE=h(3,50:58);
        MU_DATA.START_TIME=h(3,29:36);
        MU_DATA.STOP_TIME=h(3,63:70);
        MU_DATA.TITLE=h(1,:);
        MU_DATA.SAMPLE=h(1,1:10);
        MU_DATA.ORIENTATION=h(1,11:20); 
        if strcmp(MU_GEAR.FACILITY,'PSI')
        MU_DATA.TEMPERATURE=h(1,21:28);
           MU_DATA.FIELD=h(1,29:36);
        else
            MU_DATA.TEMPERATURE=h(1,21:27);
            MU_DATA.FIELD=h(1,28:35);
        end
        if strcmp(MU_GEAR.INSTRUMENT(1:3),'LTF')&&...
           strcmp(MU_DATA.FIELD(end),'T')
            MU_DATA.FIELD=[num2str(str2num(MU_DATA.FIELD(1:end-1))*1e4) 'G']; % is given in Tesla
        end
        MU_DATA.COMMENTS=h(2,:);
        ntot=sum(sum(MU_DATA.DATA(max(MU_DATA.NT0):end,:)));
        disp(['Run ' num2str(nrun) ' loaded: ' MU_DATA.TITLE(1:44) 'Total '... 
              num2str(ntot/1e6,3) ' Mev'])
    else
        disp([filename ' not found'])
    end
else
    disp('No run selected')
end


